changeset 3189:e9685c909630

mc09: Correct the description of the RTC part-number And add a reference to the instructions for wiring it up.
author Neal Crook <foofoobedoo@gmail.com>
date Sat, 20 May 2017 23:33:48 +0100
parents b0ba9d16589a
children f5e8a5030fbd
files level1/cmds/mc09rtc.asm
diffstat 1 files changed, 6 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/level1/cmds/mc09rtc.asm	Sun Apr 30 21:26:59 2017 +0100
+++ b/level1/cmds/mc09rtc.asm	Sat May 20 23:33:48 2017 +0100
@@ -1,5 +1,8 @@
 ********************************************************************
-* mc09rtc - read/write DS1802 RTC attached to multicomp09 GPIO
+* mc09rtc - read/write DS1302 RTC attached to multicomp09 GPIO
+* Details of the hook-up can be inferred from the code or see the
+* description here:
+* https://github.com/nealcrook/multicomp6809/wiki/Adding-a-RTC
 *
 * Rather than bloat the timer module (which is memory-resident)
 * this is a stand-alone utility that can either read the RTC and
@@ -42,7 +45,7 @@
 * Created.
 *
          nam   mc09rtc
-         ttl   Read/write DS1802 RTC, copy to/from system time
+         ttl   Read/write DS1302 RTC, copy to/from system time
 
          use   defsfile
 
@@ -518,7 +521,7 @@
 
 
 ********************************************************************
 * Low-level DS1802 read/write. Broken into the following parts:
 *
 * initio   - GPIO init
 * putcmd   - write 1st (cmd) byte
@@ -518,7 +521,7 @@
 
 ********************************************************************
-* Low-level DS1802 read/write. Broken into the following parts:
+* Low-level DS1302 read/write. Broken into the following parts:
 *
 * initio   - GPIO init